@@ -100,7 +100,7 @@ def period_uncertainty(periods, power):
     return period_uncertainty
 
 
-def spectra(chi2, oversampling_factor):
+def spectra(chi2, oversampling_factor, chi2_baseline):
     SR = numpy.min(chi2) / chi2
     SDE_raw = (1 - numpy.mean(SR)) / numpy.std(SR)
 
@@ -119,6 +119,7 @@ def spectra(chi2, oversampling_factor):
         # Re-normalize to range between median = 0 and peak = SDE
         # shift down to the mean being zero
         power = power - numpy.mean(power)
+        power = power_neighbour_correction(power, kernel, chi2, chi2_baseline)
         SDE = numpy.max(power / numpy.std(power))
         # scale factor to touch max=SDE
         scale = SDE / numpy.max(power)
@@ -129,6 +130,24 @@ def spectra(chi2, oversampling_factor):
 
     return SR, power_raw, power, SDE_raw, SDE
 
+def power_neighbour_correction(sde, kernel, chi2, chi2_baseline):
+    """Returns scaled power spectra taking into account the neighbours used with the given kernel that are below the
+    residuals baseline"""
+    idx = numpy.arange(kernel) + numpy.arange(len(sde) - kernel + 1)[:, None]
+    chi2_idx = chi2[idx]
+    chi2_idx_gtbaseline = [len(numpy.argwhere(chi2_window < chi2_baseline).flatten()) for chi2_window in chi2_idx]
+    # Append the first/last value at the beginning/end to match the length of
+    # data and returned median
+    first_values = chi2_idx_gtbaseline[0]
+    last_values = chi2_idx_gtbaseline[-1]
+    missing_values = len(sde) - len(chi2_idx_gtbaseline)
+    values_front = int(missing_values * 0.5)
+    values_end = missing_values - values_front
+    chi2_idx_gtbaseline = numpy.append(numpy.full(values_front, first_values), chi2_idx_gtbaseline)
+    chi2_idx_gtbaseline = numpy.append(chi2_idx_gtbaseline, numpy.full(values_end, last_values))
+    sde = sde * chi2_idx_gtbaseline / kernel
+    return sde
+
 
 def model_lightcurve(transit_times, period, t, model_transit_single):
     """Creates the model light curve for the full unfolded dataset"""
